<!-- SeleniumBase Docs -->

<h3 align="left"><img src="https://seleniumbase.github.io/cdn/img/sb_logo_b.png" alt="SeleniumBase" width="300" /></h3>

### Some organizations who have used SeleniumBase for automation:

* [MIT](https://web.mit.edu/)
* [iboss](https://www.iboss.com/)
* [Akamai](https://www.akamai.com/)
* [HubSpot](https://www.hubspot.com/)
* [Veracode](https://www.veracode.com/)
* [Autodesk](https://www.autodesk.com/)
* [Broadcom](https://www.broadcom.com/)
* [Medtronic](https://www.medtronic.com/)
* [FortressIQ](https://www.fortressiq.com/)
* [Thoma Bravo](https://www.thomabravo.com/)
* [ASICS Digital](https://www.asicsdigital.com/)
* [Texture Health](https://www.texturehealth.com/)
* [Expedia Group](https://lifeatexpediagroup.com/)
* [The Very Group](https://www.theverygroup.com/)
* [ActiveCampaign](https://www.activecampaign.com/)
* [Blue Trail Software](https://www.bluetrail.software/)
* [AutomationAnywhere](https://www.automationanywhere.com/)
* [Harvard Medical School](https://hms.harvard.edu/)
* [Singapore Institute of Tech](https://www.singaporetech.edu.sg)
* [Mississippi State University](https://www.msstate.edu/)
* [The New York Public Libary](https://www.nypl.org/)
* [Queen's University](https://www.queensu.ca/)
* [L1NNA Laboratory](https://l1nna.com/)
* [Thomson Reuters](https://www.thomsonreuters.com/)
* [CA Technologies](https://tinyurl.com/ca-technologies)
* [Optum Financial](https://www.optum.com/financial-services.html)
* [ActiveCampaign](https://www.activecampaign.com/)
* [Raid The Room](https://raidtheroom.com/)
* [First American](https://www.firstam.com/)
* [Origin Energy](https://www.originenergy.com.au/)
* [InterSystems](https://www.intersystems.com/)
* [Develop Soft](https://www.developsoft.com/)
* [Ping Identity](https://www.pingidentity.com/)
* [StreamSets](https://streamsets.com/)
* [Betterteem](https://www.betterteem.com/)
* [NerdVision](https://www.nerd.vision/)
* [SenseTime](https://www.sensetime.com/en)
* [Aeturnum](https://aeturnum.com/)
* [Cellebrite](https://www.cellebrite.com/en/home/)
* [Ben Fatto](http://www.benfatto.net.br)
* [GeoNode](http://geonode.org/)
* [Empower](https://empower.me/)
* [Streamlit](https://streamlit.io/)
* [SunCorp](https://www.suncorpgroup.com.au/)
* [Logitech](https://www.logitech.com/)
* [Modulos](https://www.modulos.ai/)
* [VMware](https://www.vmware.com/)
* [Rakuten](https://global.rakuten.com/corp/about/)
* [Nagarro](https://www.nagarro.com/en)
* [Ark PES](https://www.arkpes.com/)
* [Evereve](https://evereve.com/)
* [Yandex](https://yandex.ru/)
* [WPILib](https://wpilib.org/)
* [QBurst](https://www.qburst.com/)
* [Kinetik](https://kinetik.care/)
* [Exadel](https://exadel.com/)
* [netLex](https://netlex.io/en/)
* [Alokin](https://alokin.in/)
* [Cubic](https://www.cubic.com/)
* [Baidu](https://www.baidu.com/)
* [VPay](https://www.vpayusa.com/)
* [Seek](https://www.seek.com.au/)
* [HqO](https://www.hqo.co/)
* [PDS](https://www.pdsinc.com/)
* [Pico](https://trypico.com/)
* [Iver](https://www.iver.com/)
* And more...

--------

### Case Study:

> **HubSpot**:

In addition to using SeleniumBase for testing the UI of their content management system, HubSpot used SeleniumBase to automate the migration of website pages from their old CMS to their new one, which saved them over one million USD and a significant amount of time.

Learn how HubSpot uses SeleniumBase for website testing by reading: [Automated Testing with Selenium](https://dev.hubspot.com/blog/bid/88880/Automated-Integration-Testing-with-Selenium-at-HubSpot#hs_cos_wrapper_name)

For more reading about automation at HubSpot, see: [The Classic "QA Team" is Obsolete](https://product.hubspot.com/blog/the-classic-qa-team-is-obsolete#hs_cos_wrapper_name)
